junobuild-didc-0.0.1 is not a library.
JunoBuild-Didc
junobuild-didc is a CLI tool for generating JavaScript or TypeScript content from a DID file using the didc tool.
This utility is designed to be integrated in Juno's CLI.
Installation
You can install junobuild-didc globally using Cargo by running:
Usage
You can use the junobuild-didc command to generate JavaScript or TypeScript bindings from a DID file.
|
Example
--inputor-i: Path to the.didfile.--targetor-t: Choose eitherjsfor JavaScript ortsfor TypeScript output.--outputor-o: (Optional) Specify the output file. If omitted, the generated content will be printed to the console.
Development
Building from Source
If you want to build the tool from the source, you can clone the repository and build it yourself.
Running Tests
You can run the tests with:
License
This project is licensed under the MIT License. See the LICENSE file for details.